==> deepin-home_1.0.6.orig.tar.xz: deepin-home-1.0.6/translations/deepin-home/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Próximamente</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Discuta y comparta aquí</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Informe de errores</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Informar de los problemas encontrados</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Envíe sus sugerencias</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Cuestionario</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Únase a nosotros</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Pruebas internas</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Noticias de la Comunidad</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Preguntas</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="25"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="29"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="39"/>
        <source>Version: %1</source>
        <translation>Versión: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="40"/>
        <source>Deepin Messages</source>
        <translation>Mensajes de Deepin</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="76"/>
        <source>Unlogged</source>
        <translation>Desbloqueado</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="111"/>
        <source>Sign in</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="123"/>
        <source>Sign out</source>
        <translation>Desconectar</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Todavía no hay mensajes.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 mensajes</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Marcar todo como leído</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Ver más</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Todavía no hay cuestionarios.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Expirado el: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Rellenar</translation>
    </message>
</context>
</TS>

==> deepin-home_1.0.15.orig.tar.xz: deepin-home-1.0.15/translations/deepin-home/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Próximamente</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="52"/>
        <source>Discuss and share here</source>
        <translation>Discuta y comparta aquí</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Bug Report</source>
        <translation>Informe de errores</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="62"/>
        <source>Report issues you found</source>
        <translation>Informar de los problemas encontrados</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="70"/>
        <source>Submit your suggestions</source>
        <translation>Envíe sus sugerencias</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="84"/>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="89"/>
        <source>Questionaire</source>
        <translation>Cuestionario</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="146"/>
        <source>Join US</source>
        <translation>Únase a nosotros</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="151"/>
        <source>Internal Testing</source>
        <translation>Pruebas internas</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="165"/>
        <source>Community News</source>
        <translation>Noticias de la Comunidad</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="282"/>
        <source>Network error, please try later</source>
        <translation>Error de red, por favor intente mas tarde</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Preguntas</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>Lanzar al inicio del sistema</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>Versión: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>Desbloqueado</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="119"/>
        <source>Sign in</source>
        <translation>Iniciar sesión</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="131"/>
        <source>Sign out</source>
        <translation>Desconectar</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Todavía no hay mensajes.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="149"/>
        <source>%1 messages</source>
        <translation>%1 mensajes</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="153"/>
        <source>Mark all as read</source>
        <translation>Marcar todo como leído</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Ver más</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <location filename="../src/preloadplugin/Preload.qml" line="36"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Todavía no hay cuestionarios.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="89"/>
        <source>Expired on: %1</source>
        <translation>Expirado el: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="117"/>
        <source>Fill In</source>
        <translation>Rellenar</translation>
    </message>
</context>
</TS>
